Middleware for the OpenStack Identity API (Keystone)
====================================================

This package contains middleware modules designed to provide authentication and
authorization features to web services other than `Keystone
<https://github.com/openstack/keystone>`. The most prominent module is
``keystonemiddleware.auth_token``. This package does not expose any CLI or
Python API features.

The source is available on GitHub at:

    http://github.com/openstack/keystonemiddleware

Bugs and feature requests are tracked on Launchpad at:

    https://bugs.launchpad.net/keystonemiddleware

For any other information, refer to the parent project, Keystone:

    https://github.com/openstack/keystone

For information on contributing, see ``CONTRIBUTING.rst``.
